@@ -20,10 +20,12 @@ AUTHORS: Original programming in C and focal plane geometry solutions
  Sesame queries by Brett Morris (UW)
  Proxy Support added by Dishendra Mishra
  Deprecation warnings correctsion by Ethan Kruse
+ Updates by Tyler Pritchard, Christina Hedges
 
-VERSION: 0.7.1
+VERSION: 0.8.0
 
 WHAT'S NEW:
+    -Year 6 pointings (Sectors 70-83) now available
     -Deprecation Warning Corrections
     -Year 5 pointings (Sectors 56-69) now available
     -Added Sector Pointing override file input
@@ -787,7 +789,7 @@ class TESS_Spacecraft_Pointing_Data:
     #Hard coded spacecraft pointings by Sector
     # When adding sectors the arg2 needs to end +1 from sector
     #  due to the np.arange function ending at arg2-1
-    sectors = np.arange(1,70, dtype=int)
+    sectors = np.arange(1,84, dtype=int)
 
     # Arrays are broken up into the following sectors:
     # Line 1: Sectors 1-5 Start Year 1
@@ -808,6 +810,10 @@ class TESS_Spacecraft_Pointing_Data:
     # Line 16: S 60-63
     # Line 17: S 64-67
     # Line 18: S 68-69 END Year 5
+    # Line 19: S 70-72 START Year 6
+    # Line 20: S 73-76
+    # Line 21: S 77-80
+    # Line 22: S 81-83 END Year 6
     ### NOTE IF you add Sectors be sure to update the allowed range
     ### for sectors in argparse arguments!!!
     ras = np.array([352.6844, 16.5571, 36.3138, 55.0070, 73.5382,\
@@ -827,26 +833,34 @@ class TESS_Spacecraft_Pointing_Data:
                     324.2778,344.2275,  9.3118, 52.9755,\
                     125.6742,118.0446,135.2412,153.0613,\
                     173.2653,201.6239,259.1702,326.7691,\
-                    359.2829, 20.0449], dtype=float)
+                    359.2829, 20.0449,\
+                    24.0414,  77.3449,  133.7631, \
+                    80.6709,  261.2194, 254.9290, 253.5335, \
+                    255.8590, 260.4232, 266.0595, 275.6978, \
+                    292.5709, 309.1299, 325.8933], dtype=float)
             
     decs = np.array([-64.8531,-54.0160,-44.2590,-36.6420,-31.9349,\
-                     -30.5839,-32.6344,-37.7370,-45.3044,\
-                     -54.8165,-65.5369,-75.1256,-76.3281,\
-                     62.4756, 64.0671, 66.1422, 57.8456,\
-                     67.9575, 76.2343, 75.2520, 65.1924, 53.7434,\
-                     43.8074, 63.1181, 61.9383, 61.5637,\
-                     -72.4265,-63.0056,-52.8296,-43.3178,\
-                     -35.7835,-31.3957,-30.7848,-33.7790,\
-                     -39.6871,-47.7512,-57.3725,-67.8307,\
-                     -76.3969,\
-                     61.7450, 62.7640,  6.3337, 18.9737,\
-                     24.1343, 19.0181, 10.0922, 73.1125,\
-                     62.1038, 50.9532, 41.7577, 35.2333,\
-                     61.8190, 61.5761, 32.6073, 37.6464,\
-                     46.3448, 56.4121, 67.6524, 77.1746,\
-                     77.3113,-36.0902,-42.2415,-50.6996,\
-                     -60.8650,-71.5724,-78.7974,-74.2796,\
-                     -64.2357,-54.2315], dtype=float)
+                    -30.5839,-32.6344,-37.7370,-45.3044,\
+                    -54.8165,-65.5369,-75.1256,-76.3281,\
+                    62.4756, 64.0671, 66.1422, 57.8456,\
+                    67.9575, 76.2343, 75.2520, 65.1924, 53.7434,\
+                    43.8074, 63.1181, 61.9383, 61.5637,\
+                    -72.4265,-63.0056,-52.8296,-43.3178,\
+                    -35.7835,-31.3957,-30.7848,-33.7790,\
+                    -39.6871,-47.7512,-57.3725,-67.8307,\
+                    -76.3969,\
+                    61.7450, 62.7640,  6.3337, 18.9737,\
+                    24.1343, 19.0181, 10.0922, 73.1125,\
+                    62.1038, 50.9532, 41.7577, 35.2333,\
+                    61.8190, 61.5761, 32.6073, 37.6464,\
+                    46.3448, 56.4121, 67.6524, 77.1746,\
+                    77.3113,-36.0902,-42.2415,-50.6996,\
+                    -60.8650,-71.5724,-78.7974,-74.2796,\
+                    -64.2357,-54.2315,\
+                    9.2629,  22.2220, 16.6536, \
+                    78.8333, 72.3020, 69.9395, 66.8396, \
+                    63.8557, 61.5745, 60.3042, 32.2323, \
+                    34.6859, 39.7760, 47.1247], dtype=float)
             
     rolls = np.array([222.1532,220.4335,213.0384,202.8302,191.0517,\
                       178.6367,166.4476,155.3091,145.9163,\
@@ -865,7 +879,11 @@ class TESS_Spacecraft_Pointing_Data:
                       36.2524, 44.0100, 45.3615, 26.5121,\
                       337.3244,162.2198,151.5884,142.7405,\
                       137.2810,140.7443,173.9147,217.4678,\
-                      226.0975,222.7721], dtype=float)    
+                      226.0975,222.7721,\
+                      291.2985,274.9979,254.0304,\
+                      8.0330,213.9191,247.4882,276.6424,\
+                      302.3416,325.7085,347.5089,5.4938,\
+                      17.1317,27.7999,37.0453], dtype=float)    
 
     midtimes = np.array([ 2458339.652778, 2458368.593750, 2458396.659722, 2458424.548611, 2458451.548611, \
                          2458478.104167, 2458504.697917, 2458530.256944, 2458556.722222, \
@@ -884,7 +902,11 @@ class TESS_Spacecraft_Pointing_Data:
                          2459840.833234, 2459868.109837, 2459895.386439, 2459922.663042, \
                          2459949.939645, 2459977.216248, 2460004.492851, 2460031.769454, \
                          2460059.046057, 2460086.322659, 2460113.599262, 2460140.875865, \
-                         2460168.152468, 2460195.429071], dtype=float)
+                         2460168.152468, 2460195.429071,\
+                         2460220.5, 2460246.5, 2460272.5,\
+                         2460299 , 2460326 , 2460353 , 2460381 ,\
+                         2460409.5, 2460437.5, 2460465.5, 2460493 ,\
+                         2460519.5, 2460545.5, 2460571.5], dtype=float)
 
 
     camSeps = np.array([36.0, 12.0, 12.0, 36.0], dtype=float)
@@ -1221,7 +1243,7 @@ if __name__ == '__main__':
                         help="Filename for input Target TIC [int]; RA[deg]; Dec[dec]; in white space delimited text file Column 1, 2, and 3 respectively")
     parser.add_argument("-o", "--outputFile", type=argparse.FileType('w'), \
                         help="Optional filename for output.  Default is output to stdout ")
-    parser.add_argument("-s", "--sector", type=int, choices=range(1,70),\
+    parser.add_argument("-s", "--sector", type=int, choices=range(1,84),\
                         help="Search a single sector Number [int]")
     parser.add_argument("-x", "--combinedFits", action='store_true', \
                         help="Output detector pixel coordinates for the 'Big' multi-detector combined fits file format")
@@ -1438,4 +1460,4 @@ if __name__ == '__main__':
         idxSec = np.where(scinfo.sectors == trySector)[0][0]
         ra_deg, dec_deg = scinfo.fpgObjs[idxSec].pix2radec_nocheck_single(iCam, iCcd, [starCcdXs, starCcdYs])
         print(ra_deg, dec_deg)
-        
+        
\ No newline at end of file
